@@ -16,12 +16,6 @@ pub(crate) struct TcpRouterHandle {
     api_addr: Address,
 }
 
-impl TcpRouterHandle {
-    pub fn ctx(&self) -> &Context {
-        &self.ctx
-    }
-}
-
 #[async_trait]
 impl AsyncTryClone for TcpRouterHandle {
     async fn async_try_clone(&self) -> Result<Self> {
@@ -31,12 +25,76 @@ impl AsyncTryClone for TcpRouterHandle {
 }
 
 impl TcpRouterHandle {
+    /// Create a new `TcpRouterHandle` with the given address
     pub(crate) fn new(ctx: Context, api_addr: Address) -> Self {
         TcpRouterHandle { ctx, api_addr }
     }
+
+    /// Return a reference to the router handle's [`Context`]
+    pub fn ctx(&self) -> &Context {
+        &self.ctx
+    }
 }
 
 impl TcpRouterHandle {
+    /// Bind an incoming connection listener for this router
+    pub async fn bind(&self, addr: impl Into<SocketAddr>) -> Result<()> {
+        let socket_addr = addr.into();
+        TcpListenProcessor::start(&self.ctx, self.async_try_clone().await?, socket_addr).await
+    }
+
+    /// Establish an outgoing TCP connection on an existing transport
+    pub async fn connect<S: AsRef<str>>(&self, peer: S) -> Result<Address> {
+        let mut child_ctx = self.ctx.new_context(Address::random_local()).await?;
+
+        child_ctx
+            .send(
+                self.api_addr.clone(),
+                TcpRouterRequest::Connect {
+                    peer: peer.as_ref().to_string(),
+                },
+            )
+            .await?;
+
+        let response = child_ctx
+            .receive::<TcpRouterResponse>()
+            .await?
+            .take()
+            .body();
+
+        if let TcpRouterResponse::Connect(res) = response {
+            res
+        } else {
+            Err(TransportError::InvalidRouterResponseType.into())
+        }
+    }
+
+    /// Disconnect an outgoing TCP connection on an existing transport
+    pub async fn disconnect<S: AsRef<str>>(&self, peer: S) -> Result<()> {
+        let mut child_ctx = self.ctx.new_context(Address::random_local()).await?;
+
+        child_ctx
+            .send(
+                self.api_addr.clone(),
+                TcpRouterRequest::Disconnect {
+                    peer: peer.as_ref().to_string(),
+                },
+            )
+            .await?;
+
+        let response = child_ctx
+            .receive::<TcpRouterResponse>()
+            .await?
+            .take()
+            .body();
+
+        if let TcpRouterResponse::Disconnect(res) = response {
+            res
+        } else {
+            Err(TransportError::InvalidRouterResponseType.into())
+        }
+    }
+
     /// Register a new connection worker with this router
     pub async fn register(&self, pair: &WorkerPair) -> Result<()> {
         let tcp_address: Address = format!("{}#{}", TCP, pair.peer()).into();
@@ -69,7 +127,7 @@ impl TcpRouterHandle {
         }
     }
 
-    /// Unregister
+    /// Unregister the conenction worker for the given `Address`
     pub async fn unregister(&self, self_addr: Address) -> Result<()> {
         let mut child_ctx = self.ctx.new_context(Address::random_local()).await?;
 
@@ -93,32 +151,7 @@ impl TcpRouterHandle {
         }
     }
 
-    /// Bind an incoming connection listener for this router
-    pub async fn bind(&self, addr: impl Into<SocketAddr>) -> Result<()> {
-        let socket_addr = addr.into();
-        TcpListenProcessor::start(&self.ctx, self.async_try_clone().await?, socket_addr).await
-    }
-
-    /// Bind an incoming portal inlet connection listener for this router
-    pub async fn bind_inlet(
-        &self,
-        outlet_listener_route: impl Into<Route>,
-        addr: impl Into<SocketAddr>,
-    ) -> Result<Address> {
-        let socket_addr = addr.into();
-        let addr =
-            TcpInletListenProcessor::start(&self.ctx, outlet_listener_route.into(), socket_addr)
-                .await?;
-
-        Ok(addr)
-    }
-
-    pub async fn stop_inlet(&self, addr: impl Into<Address>) -> Result<()> {
-        self.ctx.stop_processor(addr).await?;
-
-        Ok(())
-    }
-
+    /// Resolve the given peer to a [`SocketAddr`](std::net::SocketAddr)
     pub(crate) fn resolve_peer(peer: impl Into<String>) -> Result<(SocketAddr, Vec<String>)> {
         let peer_str = peer.into();
         let peer_addr;
@@ -139,62 +172,29 @@ impl TcpRouterHandle {
             }
 
             hostnames = vec![peer_str];
-        } else {
+        }
+        // Nothing worked, return an error
+        else {
             return Err(TransportError::InvalidAddress.into());
         }
 
         Ok((peer_addr, hostnames))
     }
+}
 
-    /// Establish an outgoing TCP connection on an existing transport
-    pub async fn connect<S: AsRef<str>>(&self, peer: S) -> Result<Address> {
-        let mut child_ctx = self.ctx.new_context(Address::random_local()).await?;
+impl TcpRouterHandle {
+    /// Bind an incoming portal inlet connection listener for this router
+    pub async fn bind_inlet(
+        &self,
+        outlet_listener_route: impl Into<Route>,
+        addr: impl Into<SocketAddr>,
+    ) -> Result<Address> {
+        let socket_addr = addr.into();
+        let addr =
+            TcpInletListenProcessor::start(&self.ctx, outlet_listener_route.into(), socket_addr)
+                .await?;
 
-        child_ctx
-            .send(
-                self.api_addr.clone(),
-                TcpRouterRequest::Connect {
-                    peer: peer.as_ref().to_string(),
-                },
-            )
-            .await?;
-
-        let response = child_ctx
-            .receive::<TcpRouterResponse>()
-            .await?
-            .take()
-            .body();
-
-        if let TcpRouterResponse::Connect(res) = response {
-            res
-        } else {
-            Err(TransportError::InvalidRouterResponseType.into())
-        }
-    }
-
-    pub async fn disconnect<S: AsRef<str>>(&self, peer: S) -> Result<()> {
-        let mut child_ctx = self.ctx.new_context(Address::random_local()).await?;
-
-        child_ctx
-            .send(
-                self.api_addr.clone(),
-                TcpRouterRequest::Disconnect {
-                    peer: peer.as_ref().to_string(),
-                },
-            )
-            .await?;
-
-        let response = child_ctx
-            .receive::<TcpRouterResponse>()
-            .await?
-            .take()
-            .body();
-
-        if let TcpRouterResponse::Disconnect(res) = response {
-            res
-        } else {
-            Err(TransportError::InvalidRouterResponseType.into())
-        }
+        Ok(addr)
     }
 
     /// Establish an outgoing TCP connection for Portal Outlet
@@ -210,6 +210,13 @@ impl TcpRouterHandle {
         Ok(address)
     }
 
+    /// Stop the inlet's [`TcpInletListenProcessor`]
+    pub async fn stop_inlet(&self, addr: impl Into<Address>) -> Result<()> {
+        self.ctx.stop_processor(addr).await?;
+        Ok(())
+    }
+
+    /// Stop the inlet's [`TcpPortalWorker`]
     pub async fn stop_outlet(&self, addr: impl Into<Address>) -> Result<()> {
         self.ctx.stop_worker(addr).await?;
         Ok(())
