@@ -5,8 +5,13 @@ use ockam_node::Context;
 use ockam_transport_core::TransportError;
 use std::net::SocketAddr;
 use tokio::net::TcpListener;
-use tracing::{debug, trace};
+use tracing::debug;
 
+/// A TCP Listen processor
+///
+/// TCP listen processors are created by `TcpTransport`
+/// after a call is made to
+/// [`TcpTransport::listen`](crate::TcpTransport::listen).
 pub(crate) struct TcpListenProcessor {
     inner: TcpListener,
     router_handle: TcpRouterHandle,
@@ -18,8 +23,6 @@ impl TcpListenProcessor {
         router_handle: TcpRouterHandle,
         addr: SocketAddr,
     ) -> Result<()> {
-        let waddr = Address::random_local();
-
         debug!("Binding TcpListener to {}", addr);
         let inner = TcpListener::bind(addr)
             .await
@@ -29,7 +32,8 @@ impl TcpListenProcessor {
             router_handle,
         };
 
-        ctx.start_processor(waddr, worker).await?;
+        ctx.start_processor(Address::random_local(), worker).await?;
+
         Ok(())
     }
 }
@@ -43,10 +47,11 @@ impl Processor for TcpListenProcessor {
     }
 
     async fn process(&mut self, ctx: &mut Self::Context) -> Result<bool> {
-        trace!("Waiting for incoming TCP connection...");
+        debug!("Waiting for incoming TCP connection...");
 
         // Wait for an incoming connection
         let (stream, peer) = self.inner.accept().await.map_err(TransportError::from)?;
+        debug!("TCP connection accepted");
 
         let handle_clone = self.router_handle.async_try_clone().await?;
         // And spawn a connection worker for it
@@ -54,6 +59,7 @@ impl Processor for TcpListenProcessor {
 
         // Register the connection with the local TcpRouter
         self.router_handle.register(&pair).await?;
+        debug!("TCP connection registered");
 
         Ok(true)
     }
